#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['deal',
 'deal._cli',
 'deal._decorators',
 'deal.linter',
 'deal.linter._extractors']

package_data = \
{'': ['*'],
 'deal.linter': ['stubs/*',
                 'stubs/cpython/*',
                 'stubs/cpython/http/*',
                 'stubs/cpython/urllib/*',
                 'stubs/dateutil/*',
                 'stubs/dateutil/parser/*',
                 'stubs/dateutil/tz/*',
                 'stubs/dateutil/zoneinfo/*',
                 'stubs/marshmallow/*',
                 'stubs/pytz/*',
                 'stubs/requests/*',
                 'stubs/urllib3/*',
                 'stubs/urllib3/contrib/*',
                 'stubs/urllib3/util/*']}

install_requires = \
['astroid', 'deal-solver', 'hypothesis', 'pygments', 'typeguard', 'vaa>=0.2.1']

extras_require = \
{'docs': ['m2r2', 'recommonmark', 'sphinx', 'sphinx-rtd-theme'],
 'lint': ['flake8', 'flake8-commas', 'flake8-quotes', 'mypy>=0.900'],
 'test': ['coverage',
          'pytest-cov',
          'isort',
          'marshmallow',
          'pytest',
          'urllib3']}

entry_points = \
{'flake8.extension': ['DEAL = deal.linter:Checker']}

setup(name='deal',
      version='4.7.1',
      description='**Deal** is a Python library for [design by contract][wiki] (DbC) programming.',
      author='Gram',
      author_email='gram@orsinium.dev',
      url='https://github.com/orsinium/deal',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.7',
     )
